@@ -11,27 +11,28 @@
 #include "kirc.h"
 #include "terminal.h"
 #include "ansi.h"
+#include "utf8.h"
 
-typedef enum {
-    EDITOR_EVENT_NONE = 0,
-    EDITOR_EVENT_SEND,
-    EDITOR_EVENT_TERMINATE
-} editor_event_t;
+enum editor_state {
+    EDITOR_STATE_NONE = 0,
+    EDITOR_STATE_SEND,
+    EDITOR_STATE_TERMINATE
+};
 
-typedef struct {
-    kirc_t *ctx;
-    editor_event_t event;
+struct editor {
+    struct kirc_context *ctx;
+    enum editor_state state;
     char scratch[MESSAGE_MAX_LEN];
     char history[KIRC_HISTORY_SIZE][MESSAGE_MAX_LEN];
     int head;
     int count;
     int position; /* -1 when not browsing history, otherwise index into history[] */
     int cursor;
-} editor_t;
+};
 
-char *editor_last_entry(editor_t *editor);
-int editor_init(editor_t *editor, kirc_t *ctx);
-int editor_process_key(editor_t *editor);
-int editor_handle(editor_t *editor);
+char *editor_last_entry(struct editor *editor);
+int editor_init(struct editor *editor, struct kirc_context *ctx);
+int editor_process_key(struct editor *editor);
+int editor_handle(struct editor *editor);
 
 #endif  // __KIRC_EDITOR_H
