@@ -10,7 +10,9 @@
 
 #include "kirc.h"
 
-char * safecpy(char *s1, const char *s2, size_t n);
-int secure_zero(void *ptr, size_t n);
+int safecpy(char *s1, const char *s2, size_t n);
+int memzero(void *s, size_t n);
+
+char *find_message_end(const char *buffer, size_t len);
 
 #endif  // __KIRC_HELPER_H
