@@ -9,17 +9,18 @@
 #define __KIRC_TERMINAL_H
 
 #include "kirc.h"
+#include "ansi.h"
 
-typedef struct {
-    kirc_t *ctx;
+struct terminal {
+    struct kirc_context *ctx;
     struct termios original;
     int raw_mode_enabled;
-} terminal_t;
+};
 
 int terminal_columns(int tty_fd);
-
-int terminal_init(terminal_t *terminal, kirc_t *ctx);
-int terminal_enable_raw(terminal_t *terminal);
-void terminal_disable_raw(terminal_t *terminal);
+int terminal_init(struct terminal *terminal,
+        struct kirc_context *ctx);
+int terminal_enable_raw(struct terminal *terminal);
+void terminal_disable_raw(struct terminal *terminal);
 
 #endif  // __KIRC_TERMINAL_H
